# Constants
SCREEN_WIDTH = 1280
SCREEN_HEIGHT = 720
SCREEN_TITLE = "Wizard Detention"

TILE_SCALING = 1
WIZARD_SCALING = 1
FAMILIAR_SCALING = 1
PLATFORM_SCALING = 1.8

SPAWN_X = 100
SPAWN_Y = 120

PLAYER_MS = 5
PLAYER_JS = 15
GRAVITY = 1
